@@ -207,6 +207,7 @@ impl<W> ser::SerializeSeq for SeqSerializer<W> where W: Write {
         if !self.is_empty {
             writeln!(self.output).map_err(Error::failed_write)?;
         }
+        self.is_empty = false;
         value.serialize(NonSeqSerializer { writer: &mut self.output, wrap_long_lines: self.wrap_long_lines })
     }
 
@@ -791,6 +792,21 @@ mod tests {
         assert_eq!(out, "Bar: baz,\n     bitcoin\n");
     }
 
+    #[test]
+    fn struct_seq() {
+        #[derive(serde_derive::Serialize)]
+        #[serde(rename_all = "PascalCase")]
+        struct Foo {
+            bar: &'static str,
+            baz: &'static str,
+        }
+
+        let mut out = String::new();
+        vec![Foo { bar: "bar value 1", baz: "baz value 1" }, Foo { bar: "bar value 2", baz: "baz value 2" }]
+            .serialize(Serializer::new(&mut out)).expect("Failed to serialize");
+        assert_eq!(out, "Bar: bar value 1\nBaz: baz value 1\n\nBar: bar value 2\nBaz: baz value 2\n");
+    }
+
     #[test]
     fn field_writer_empty() {
         let mut output = String::new();
